@@ -7,17 +7,22 @@
 #ifndef MM_MACROS_H
 #define MM_MACROS_H
 
-# define MM_GLOBAL_STATIC_STRUCT_NAME(NAME)
+#define MM_GLOBAL_STATIC_STRUCT_NAME(NAME)
 typedef void (*MmCleanUpFunction)();
 class MmCleanUpGlobalStatic
 {
-    public:
-        MmCleanUpFunction func;
+public:
+    MmCleanUpFunction func;
 
-        inline ~MmCleanUpGlobalStatic() { func(); }
+    inline ~MmCleanUpGlobalStatic()
+    {
+        func();
+    }
 };
 
 #define MM_GLOBAL_STATIC(TYPE, NAME) MM_GLOBAL_STATIC_WITH_ARGS(TYPE, NAME, ())
+
+/* clang-format off */
 #define MM_GLOBAL_STATIC_WITH_ARGS(TYPE, NAME, ARGS)                            \
 static QBasicAtomicPointer<TYPE > _mm_static_##NAME = Q_BASIC_ATOMIC_INITIALIZER(0); \
 static bool _mm_static_##NAME##_destroyed;                                      \
@@ -64,5 +69,6 @@ static struct MM_GLOBAL_STATIC_STRUCT_NAME(NAME)
         delete x;                                                              \
     }                                                                          \
 } NAME;
+/* clang-format on */
 
 #endif
